@@ -1,29 +1,28 @@
 # frozen_string_literal: true
 
 require 'helper'
+require 'rack/helper'
 
-class Adsf::Test::Rack::IndexFileFinder < MiniTest::Test
+class Adsf::Test::Rack::IndexFileFinder < Minitest::Test
   include Rack::Test::Methods
   include Adsf::Test::Helpers
+  include Adsf::Test::Rack::Helpers
 
   def app
     ::Adsf::Rack::IndexFileFinder.new(
       stub_app,
-      **(@options || {}).merge(root: '.'),
+      **app_options,
     )
   end
 
-  def stub_app
-    Rack::File.new('.')
-  end
-
   def test_get_file
     # Create test file
     File.write('motto.txt', 'More human than human')
 
     # Request test file
     get '/motto.txt'
-    assert last_response.ok?
+
+    assert_predicate last_response, :ok?
     assert_equal 'More human than human', last_response.body
   end
 
@@ -33,7 +32,8 @@ class Adsf::Test::Rack::IndexFileFinder < MiniTest::Test
 
     # Request test directory
     get '/replicants'
-    assert last_response.redirect?
+
+    assert_predicate last_response, :redirect?
     assert_equal '/replicants/', last_response.location
   end
 
@@ -43,7 +43,8 @@ class Adsf::Test::Rack::IndexFileFinder < MiniTest::Test
 
     # Request test directory
     get '/replicants/'
-    assert last_response.not_found?
+
+    assert_predicate last_response, :not_found?
   end
 
   def test_get_dir_with_index_file_without_slash
@@ -55,7 +56,8 @@ class Adsf::Test::Rack::IndexFileFinder < MiniTest::Test
 
     # Request test directory
     get '/replicants'
-    assert last_response.redirect?
+
+    assert_predicate last_response, :redirect?
     assert_equal '/replicants/', last_response.location
   end
 
@@ -68,12 +70,13 @@ class Adsf::Test::Rack::IndexFileFinder < MiniTest::Test
 
     # Request test directory
     get '/replicants/'
-    assert last_response.ok?
+
+    assert_predicate last_response, :ok?
     assert_equal 'Leon, Roy, Pris, Zhora, etc.', last_response.body
   end
 
   def test_get_dir_with_custom_index_file
-    @options = { index_filenames: ['list.xml'] }
+    @app_options = { index_filenames: ['list.xml'] }
 
     # Create test directory
     FileUtils.mkdir('replicants')
@@ -83,7 +86,8 @@ class Adsf::Test::Rack::IndexFileFinder < MiniTest::Test
 
     # Request test directory
     get '/replicants/'
-    assert last_response.ok?
+
+    assert_predicate last_response, :ok?
     assert_equal 'Leon, Roy, Pris, Zhora, etc.', last_response.body
   end
 
@@ -93,7 +97,8 @@ class Adsf::Test::Rack::IndexFileFinder < MiniTest::Test
 
     # Request test directory
     get '/animal%20replicants'
-    assert last_response.redirect?
+
+    assert_predicate last_response, :redirect?
     assert_equal '/animal%20replicants/', last_response.location
   end
 end
